@@ -39,7 +39,7 @@ from pathlib import Path
 def count_digits(value):
     if np.isnan(value): return 0, 0
     if math.isinf(value): return 0, 0
-    parts = str(float(value)).split(".")
+    parts = np.format_float_positional(value).split(".")
     n = len(parts[0].lstrip("0"))
     m = len(parts[1].rstrip("0"))
     return n, m
@@ -53,7 +53,7 @@ def format_alias_doc(alias, target):
 
 def format_floats(seq):
     precision = dataiter.PRINT_FLOAT_PRECISION
-    if any(0 < x < 1/10**precision or x > 10**16 - 1 for x in seq):
+    if any(0 < abs(x) < 1/10**precision or abs(x) > 10**16 - 1 for x in seq):
         # Format tiny and huge numbers in scientific notation.
         f = np.format_float_scientific
         return [f(x, precision=precision, trim="-") for x in seq]
